{
    "$graph": [
        {
            "class": "Workflow",
            "doc": "ChIP-seq 01 QC - reads: SE",
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "doc": "Adapters file",
                    "type": "File",
                    "id": "#main/default_adapters_file"
                },
                {
                    "doc": "Input fastq files",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#main/input_fastq_files"
                },
                {
                    "doc": "Number of threads.",
                    "type": "int",
                    "id": "#main/nthreads"
                }
            ],
            "steps": [
                {
                    "run": "#diff.cwl",
                    "scatterMethod": "dotproduct",
                    "scatter": [
                        "#main/compare_read_counts/file1",
                        "#main/compare_read_counts/file2"
                    ],
                    "in": [
                        {
                            "source": "#main/count_raw_reads/output_read_count",
                            "id": "#main/compare_read_counts/file1"
                        },
                        {
                            "source": "#main/count_fastqc_reads/output_fastqc_read_count",
                            "id": "#main/compare_read_counts/file2"
                        }
                    ],
                    "out": [
                        "#main/compare_read_counts/result"
                    ],
                    "id": "#main/compare_read_counts"
                },
                {
                    "run": "#count-fastqc-reads.cwl",
                    "scatterMethod": "dotproduct",
                    "scatter": [
                        "#main/count_fastqc_reads/input_fastqc_data",
                        "#main/count_fastqc_reads/input_basename"
                    ],
                    "in": [
                        {
                            "source": "#main/extract_basename/output_basename",
                            "id": "#main/count_fastqc_reads/input_basename"
                        },
                        {
                            "source": "#main/extract_fastqc_data/output_fastqc_data_file",
                            "id": "#main/count_fastqc_reads/input_fastqc_data"
                        }
                    ],
                    "out": [
                        "#main/count_fastqc_reads/output_fastqc_read_count"
                    ],
                    "id": "#main/count_fastqc_reads"
                },
                {
                    "run": "#count-fastq-reads.cwl",
                    "scatterMethod": "dotproduct",
                    "scatter": [
                        "#main/count_raw_reads/input_fastq_file",
                        "#main/count_raw_reads/input_basename"
                    ],
                    "in": [
                        {
                            "source": "#main/extract_basename/output_basename",
                            "id": "#main/count_raw_reads/input_basename"
                        },
                        {
                            "source": "#main/input_fastq_files",
                            "id": "#main/count_raw_reads/input_fastq_file"
                        }
                    ],
                    "out": [
                        "#main/count_raw_reads/output_read_count"
                    ],
                    "id": "#main/count_raw_reads"
                },
                {
                    "run": "#extract-basename.cwl",
                    "scatter": "#main/extract_basename/input_file",
                    "in": [
                        {
                            "source": "#main/input_fastq_files",
                            "id": "#main/extract_basename/input_file"
                        }
                    ],
                    "out": [
                        "#main/extract_basename/output_basename"
                    ],
                    "id": "#main/extract_basename"
                },
                {
                    "run": "#extract_fastqc_data.cwl",
                    "scatterMethod": "dotproduct",
                    "scatter": [
                        "#main/extract_fastqc_data/input_qc_report_file",
                        "#main/extract_fastqc_data/input_basename"
                    ],
                    "in": [
                        {
                            "source": "#main/extract_basename/output_basename",
                            "id": "#main/extract_fastqc_data/input_basename"
                        },
                        {
                            "source": "#main/fastqc/output_qc_report_file",
                            "id": "#main/extract_fastqc_data/input_qc_report_file"
                        }
                    ],
                    "out": [
                        "#main/extract_fastqc_data/output_fastqc_data_file"
                    ],
                    "id": "#main/extract_fastqc_data"
                },
                {
                    "run": "#fastqc.cwl",
                    "scatter": "#main/fastqc/input_fastq_file",
                    "in": [
                        {
                            "source": "#main/input_fastq_files",
                            "id": "#main/fastqc/input_fastq_file"
                        },
                        {
                            "source": "#main/nthreads",
                            "id": "#main/fastqc/threads"
                        }
                    ],
                    "out": [
                        "#main/fastqc/output_qc_report_file"
                    ],
                    "id": "#main/fastqc"
                },
                {
                    "run": "#overrepresented_sequence_extract.cwl",
                    "scatterMethod": "dotproduct",
                    "scatter": [
                        "#main/overrepresented_sequence_extract/input_fastqc_data",
                        "#main/overrepresented_sequence_extract/input_basename"
                    ],
                    "in": [
                        {
                            "source": "#main/default_adapters_file",
                            "id": "#main/overrepresented_sequence_extract/default_adapters_file"
                        },
                        {
                            "source": "#main/extract_basename/output_basename",
                            "id": "#main/overrepresented_sequence_extract/input_basename"
                        },
                        {
                            "source": "#main/extract_fastqc_data/output_fastqc_data_file",
                            "id": "#main/overrepresented_sequence_extract/input_fastqc_data"
                        }
                    ],
                    "out": [
                        "#main/overrepresented_sequence_extract/output_custom_adapters"
                    ],
                    "id": "#main/overrepresented_sequence_extract"
                }
            ],
            "id": "#main",
            "outputs": [
                {
                    "outputSource": "#main/count_raw_reads/output_read_count",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#main/output_count_raw_reads"
                },
                {
                    "outputSource": "#main/overrepresented_sequence_extract/output_custom_adapters",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#main/output_custom_adapters"
                },
                {
                    "outputSource": "#main/compare_read_counts/result",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#main/output_diff_counts"
                },
                {
                    "doc": "FastQC data files for paired read 1",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/extract_fastqc_data/output_fastqc_data_file",
                    "id": "#main/output_fastqc_data_files"
                },
                {
                    "doc": "FastQC reports in zip format for paired read 1",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/fastqc/output_qc_report_file",
                    "id": "#main/output_fastqc_report_files"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "doc": "Extracts read count from fastqc_data.txt",
            "hints": [
                {
                    "dockerPull": "reddylab/workflow-utils:ggr",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "id": "#count-fastqc-reads.cwl/input_basename"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#count-fastqc-reads.cwl/input_fastqc_data"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.input_basename + '.fastqc-read_count.txt')"
                    },
                    "id": "#count-fastqc-reads.cwl/output_fastqc_read_count"
                }
            ],
            "baseCommand": "count-fastqc_data-reads.sh",
            "stdout": "$(inputs.input_basename + '.fastqc-read_count.txt')",
            "id": "#count-fastqc-reads.cwl"
        },
        {
            "class": "CommandLineTool",
            "doc": "Compares 2 files",
            "hints": [
                {
                    "dockerPull": "reddylab/workflow-utils:ggr",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "boolean",
                    "default": true,
                    "inputBinding": {
                        "prefix": "--brief",
                        "position": 3
                    },
                    "id": "#diff.cwl/brief"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#diff.cwl/file1"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#diff.cwl/file2"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "stdout.txt"
                    },
                    "id": "#diff.cwl/result"
                }
            ],
            "baseCommand": "diff",
            "stdout": "stdout.txt",
            "id": "#diff.cwl"
        },
        {
            "class": "CommandLineTool",
            "doc": "Unzips a zipped fastqc report and returns the fastqc_data.txt file. Unzips the file to pipe and uses redirection",
            "hints": [
                {
                    "dockerPull": "dukegcb/fastqc",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "default": "*/fastqc_data.txt",
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#extract_fastqc_data.cwl/extract_pattern"
                },
                {
                    "type": "string",
                    "id": "#extract_fastqc_data.cwl/input_basename"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#extract_fastqc_data.cwl/input_qc_report_file"
                },
                {
                    "type": "boolean",
                    "default": true,
                    "inputBinding": {
                        "prefix": "-p",
                        "position": 1
                    },
                    "id": "#extract_fastqc_data.cwl/pipe"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.input_basename + '.fastqc_data.txt')"
                    },
                    "id": "#extract_fastqc_data.cwl/output_fastqc_data_file"
                }
            ],
            "baseCommand": "unzip",
            "stdout": "$(inputs.input_basename + '.fastqc_data.txt')",
            "id": "#extract_fastqc_data.cwl"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "dukegcb/fastqc",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "default": "fastq",
                    "inputBinding": {
                        "position": 3,
                        "prefix": "--format"
                    },
                    "id": "#fastqc.cwl/format"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 4
                    },
                    "id": "#fastqc.cwl/input_fastq_file"
                },
                {
                    "type": "boolean",
                    "default": true,
                    "inputBinding": {
                        "prefix": "--noextract",
                        "position": 2
                    },
                    "id": "#fastqc.cwl/noextract"
                },
                {
                    "type": "int",
                    "default": 1,
                    "inputBinding": {
                        "position": 5,
                        "prefix": "--threads"
                    },
                    "id": "#fastqc.cwl/threads"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.input_fastq_file.path.replace(/^.*[\\\\\\/]/, \"\").replace(/\\.[^/.]+$/, '') + \"_fastqc.zip\")"
                    },
                    "id": "#fastqc.cwl/output_qc_report_file"
                }
            ],
            "baseCommand": "fastqc",
            "arguments": [
                {
                    "valueFrom": "$(runtime.tmpdir)",
                    "prefix": "--dir",
                    "position": 5
                },
                {
                    "valueFrom": "$(runtime.outdir)",
                    "prefix": "-o",
                    "position": 5
                }
            ],
            "id": "#fastqc.cwl"
        },
        {
            "class": "CommandLineTool",
            "hints": [
                {
                    "dockerPull": "reddylab/overrepresented_sequence_extract:1.0",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "doc": "Adapters file in fasta format",
                    "id": "#overrepresented_sequence_extract.cwl/default_adapters_file"
                },
                {
                    "type": "string",
                    "doc": "Name of the sample - used as a base name for generating output files",
                    "id": "#overrepresented_sequence_extract.cwl/input_basename"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "doc": "fastqc_data.txt file from a fastqc report",
                    "id": "#overrepresented_sequence_extract.cwl/input_fastqc_data"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.input_basename + '.custom_adapters.fasta')"
                    },
                    "id": "#overrepresented_sequence_extract.cwl/output_custom_adapters"
                }
            ],
            "baseCommand": "overrepresented_sequence_extract.py",
            "arguments": [
                {
                    "valueFrom": "$(inputs.input_basename + '.custom_adapters.fasta')",
                    "position": 3
                }
            ],
            "id": "#overrepresented_sequence_extract.cwl"
        },
        {
            "class": "CommandLineTool",
            "doc": "Counts reads in a fastq file",
            "hints": [
                {
                    "dockerPull": "reddylab/workflow-utils:ggr",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "id": "#count-fastq-reads.cwl/input_basename"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#count-fastq-reads.cwl/input_fastq_file"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.input_basename + '.read_count.txt')"
                    },
                    "id": "#count-fastq-reads.cwl/output_read_count"
                }
            ],
            "baseCommand": "count-fastq-reads.sh",
            "stdout": "$(inputs.input_basename + '.read_count.txt')",
            "id": "#count-fastq-reads.cwl"
        },
        {
            "class": "CommandLineTool",
            "doc": "Extracts the base name of a file",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "reddylab/workflow-utils:ggr",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#extract-basename.cwl/input_file"
                }
            ],
            "outputs": [
                {
                    "type": "string",
                    "outputBinding": {
                        "outputEval": "$(inputs.input_file.path.substr(inputs.input_file.path.lastIndexOf('/') + 1, inputs.input_file.path.lastIndexOf('.') - (inputs.input_file.path.lastIndexOf('/') + 1)))"
                    },
                    "id": "#extract-basename.cwl/output_basename"
                }
            ],
            "baseCommand": "echo",
            "id": "#extract-basename.cwl"
        }
    ],
    "cwlVersion": "v1.0"
}
